package App::WordListUtils;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-05-22'; # DATE
our $DIST = 'App-WordListUtils'; # DIST
our $VERSION = '0.002'; # VERSION

use 5.010001;

1;
# ABSTRACT: Collection of CLI utilities related to WordList

__END__

=pod

=encoding UTF-8

=head1 NAME

App::WordListUtils - Collection of CLI utilities related to WordList

=head1 VERSION

This document describes version 0.002 of App::WordListUtils (from Perl distribution App-WordListUtils), released on 2020-05-22.

=head1 SYNOPSIS

This distribution provides the following command-line utilities related to
L<WordList>:

=over

=item * L<list-wordlist-modules>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-WordListUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-WordListUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-WordListUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<WordList>

L<wordlist> which is distributed separately (with L<App::wordlist>)

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
